@@ -6,7 +6,7 @@
 ;; Keywords: help
 ;; URL: https://github.com/astoff/devdocs.el
 ;; Package-Requires: ((emacs "27.1"))
-;; Version: 0.6
+;; Version: 0.6.1
 
 ;; This program is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -316,7 +316,9 @@ already installed, reinstall it."
   "Go to the original position in a DevDocs buffer."
   (interactive)
   (goto-char (point-min))
-  (when-let ((_ shr-target-id)
+  (when-let ((frag (let-alist (car devdocs--stack)
+                     (or .fragment (devdocs--path-fragment .path))))
+             (shr-target-id (url-unhex-string frag))
              (pred (if (fboundp 'shr--set-target-ids) #'member t)) ;; shr change in Emacs 29
              (match (text-property-search-forward 'shr-target-id shr-target-id pred)))
     (goto-char (prop-match-beginning match))))
@@ -484,22 +486,20 @@ fragment part of ENTRY.path."
             (file (expand-file-name (format "%s/%s.html"
                                             .doc.slug
                                             (url-hexify-string (devdocs--path-file .path)))
-                                    devdocs-data-dir))
-            (shr-target-id (when-let ((frag (or .fragment (devdocs--path-fragment .path))))
-                             (url-unhex-string frag))))
+                                    devdocs-data-dir)))
         (erase-buffer)
         ;; TODO: cl-progv here for shr settings?
         (shr-insert-document
          (with-temp-buffer
            (insert-file-contents file)
-           (libxml-parse-html-region (point-min) (point-max))))
-        (devdocs-goto-target))
+           (libxml-parse-html-region (point-min) (point-max)))))
       (set-buffer-modified-p nil)
       (setq-local devdocs-current-docs (list .doc.slug))
       (push entry devdocs--stack)
       (setq-local list-buffers-directory (format-mode-line devdocs-header-line
                                                            nil nil
                                                            (current-buffer)))
+      (devdocs-goto-target)
       (current-buffer))))
 
 (defun devdocs--revert-buffer (&rest _args)
